@@ -24,7 +24,7 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)
 
-(* $Id: postgresql.ml,v 1.2 2004/01/29 22:46:09 mottl Exp $ *)
+(* $Id: postgresql.ml,v 1.3 2004/06/29 21:14:05 mottl Exp $ *)
 
 open Printf
 
@@ -327,7 +327,7 @@ object
   method get_all_lst =
     let lst_ref = ref [] in
     let nfields_1 = nfields - 1 in
-    for t = ntuples downto 0 do
+    for t = ntuples - 1 downto 0 do
       let tpl_ref = ref [] in
       for i = nfields_1 downto 0 do
         tpl_ref := Stub.getvalue res t i :: !tpl_ref
